@@ -32,3 +32,14 @@ JSON_INDENT = 2
 # Train / Test
 TRAIN_ID = 0
 TEST_ID = 1
+
+# Extensions
+COLOR_IMAGE_EXTS = [".png", ".jpg"]
+INTR_EXTENSION = ".intr"
+
+# Image constants
+MIN_DEPTH = 0.25
+MAX_DEPTH = 1.25
+MAX_IR = 65535
+METERS_TO_MM = 1000.0
+MM_TO_METERS = 1.0 / METERS_TO_MM
